==> jc-1.4.0.tar.gz: gnu/xml/xpath/Test.c <==
// public abstract class gnu.xml.xpath.Test

// class file dependencies
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 2f4d9ed11c447a44 org_w3c_dom_Node

// header file dependencies
// @dep_header gnu_xml_xpath_Test
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_w3c_dom_Node

#include "jc_defs.h"

#include "gnu/xml/xpath/Test.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/w3c/dom/Node.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_xml_xpath_Test$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_xml_xpath_Test$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_xml_xpath_Test$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_xml_xpath_Test$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_Test$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_xml_xpath_Test$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_xpath_Test$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_xpath_Test, _init$52f4ad9f2989aeee);

void
_jc_gnu_xml_xpath_Test$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_xml_xpath_Test$object *this)
{
	struct _jc_gnu_xml_xpath_Test$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(48);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract gnu.xml.xpath.Test clone(java.lang.Object)
//

static const unsigned char _jc_gnu_xml_xpath_Test$param_ptypes$clone$73a8d2a4d673dd95[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_gnu_xml_xpath_Test$param_types$clone$73a8d2a4d673dd95[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_gnu_xml_xpath_Test$method_info$clone$73a8d2a4d673dd95 = {
	.name=			"clone",
	.signature=		"(Ljava/lang/Object;)Lgnu/xml/xpath/Test;",
	.class=			&_jc_gnu_xml_xpath_Test$type,
	.param_types=		&_jc_gnu_xml_xpath_Test$param_types$clone$73a8d2a4d673dd95,
	.return_type=		&_jc_gnu_xml_xpath_Test$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_Test$param_ptypes$clone$73a8d2a4d673dd95,
	.signature_hash=	_JC_JLONG(0x73a8d2a4d673dd95),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_gnu_xml_xpath_Test$method$clone$73a8d2a4d673dd95,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_xpath_Test$vtable, gnu_xml_xpath_Test.clone$73a8d2a4d673dd95) / sizeof(void *),
	.num_parameters=	1,
};

_jc_gnu_xml_xpath_Test$object *
_jc_gnu_xml_xpath_Test$method$clone$73a8d2a4d673dd95(_jc_env *const env, _jc_gnu_xml_xpath_Test$object *this, _jc_java_lang_Object$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_gnu_xml_xpath_Test$method_info$clone$73a8d2a4d673dd95);
}

//
// public abstract boolean matches(org.w3c.dom.Node, int, int)
//

static const unsigned char _jc_gnu_xml_xpath_Test$param_ptypes$matches$528a77e426fd27f8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_INT, _JC_TYPE_INT, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_gnu_xml_xpath_Test$param_types$matches$528a77e426fd27f8[] = {
	&_jc_org_w3c_dom_Node$type,
	&_jc_int$prim$type,
	&_jc_int$prim$type
};

_jc_method _jc_gnu_xml_xpath_Test$method_info$matches$528a77e426fd27f8 = {
	.name=			"matches",
	.signature=		"(Lorg/w3c/dom/Node;II)Z",
	.class=			&_jc_gnu_xml_xpath_Test$type,
	.param_types=		&_jc_gnu_xml_xpath_Test$param_types$matches$528a77e426fd27f8,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_Test$param_ptypes$matches$528a77e426fd27f8,
	.signature_hash=	_JC_JLONG(0x528a77e426fd27f8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_gnu_xml_xpath_Test$method$matches$528a77e426fd27f8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_xpath_Test$vtable, gnu_xml_xpath_Test.matches$528a77e426fd27f8) / sizeof(void *),
	.num_parameters=	3,
};

jboolean
_jc_gnu_xml_xpath_Test$method$matches$528a77e426fd27f8(_jc_env *const env, _jc_gnu_xml_xpath_Test$object *this, _jc_object *param0, jint param1, jint param2)
{
	_JC_ABSTRACT_METHOD(env, &_jc_gnu_xml_xpath_Test$method_info$matches$528a77e426fd27f8);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_xpath_Test$methods[] = {
	&_jc_gnu_xml_xpath_Test$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_xml_xpath_Test$method_info$clone$73a8d2a4d673dd95,
	&_jc_gnu_xml_xpath_Test$method_info$matches$528a77e426fd27f8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_xpath_Test$instanceof_hash_bucket_23[] = {
	&_jc_gnu_xml_xpath_Test$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_xpath_Test$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_xpath_Test$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[23]=	_jc_gnu_xml_xpath_Test$instanceof_hash_bucket_23,
	[113]=	_jc_gnu_xml_xpath_Test$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_xpath_Test$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "org/w3c/dom/Node",	_JC_JLONG(0x2f4d9ed11c447a44) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_xpath_Test$vtype _jc_gnu_xml_xpath_Test$type = {
    .type= {
	.name=			"gnu/xml/xpath/Test",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xd99963ba20fa6197),
		.source_file=		"Test.java",
		.instance_size=		sizeof(_jc_gnu_xml_xpath_Test$refs) + sizeof(_jc_gnu_xml_xpath_Test$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_xml_xpath_Test$methods) / sizeof(*_jc_gnu_xml_xpath_Test$methods),
		.methods=		_jc_gnu_xml_xpath_Test$methods,
		.instanceof_hash_table=	_jc_gnu_xml_xpath_Test$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_xpath_Test$class_depends) / sizeof(*_jc_gnu_xml_xpath_Test$class_depends),
		.class_depends=		_jc_gnu_xml_xpath_Test$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_xpath_Test= {
	    .clone$73a8d2a4d673dd95=
		&_jc_gnu_xml_xpath_Test$method$clone$73a8d2a4d673dd95,
	    .matches$528a77e426fd27f8=
		&_jc_gnu_xml_xpath_Test$method$matches$528a77e426fd27f8,
	},
    }
};

==> jc-1.4.5.tar.gz: gnu/xml/xpath/Test.c <==
// public abstract class gnu.xml.xpath.Test

// class file dependencies
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 2f4d9ed11c447a44 org_w3c_dom_Node

// header file dependencies
// @dep_header gnu_xml_xpath_Test
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_w3c_dom_Node

#include "jc_defs.h"

#include "gnu/xml/xpath/Test.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/w3c/dom/Node.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_xml_xpath_Test$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_xml_xpath_Test$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_xml_xpath_Test$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_xml_xpath_Test$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_Test$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_xml_xpath_Test$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_xpath_Test$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_xpath_Test, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_gnu_xml_xpath_Test$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_xml_xpath_Test$object *this)
{
	struct _jc_gnu_xml_xpath_Test$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(48);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract gnu.xml.xpath.Test clone(java.lang.Object)
//

static const unsigned char _jc_gnu_xml_xpath_Test$param_ptypes$clone$73a8d2a4d673dd95[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_gnu_xml_xpath_Test$param_types$clone$73a8d2a4d673dd95[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_gnu_xml_xpath_Test$method_info$clone$73a8d2a4d673dd95 = {
	.name=			"clone",
	.signature=		"(Ljava/lang/Object;)Lgnu/xml/xpath/Test;",
	.class=			&_jc_gnu_xml_xpath_Test$type,
	.param_types=		&_jc_gnu_xml_xpath_Test$param_types$clone$73a8d2a4d673dd95,
	.return_type=		&_jc_gnu_xml_xpath_Test$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_Test$param_ptypes$clone$73a8d2a4d673dd95,
	.signature_hash=	_JC_JLONG(0x73a8d2a4d673dd95),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_gnu_xml_xpath_Test$method$clone$73a8d2a4d673dd95,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_xpath_Test$vtable, gnu_xml_xpath_Test.clone$73a8d2a4d673dd95) / sizeof(void *),
	.num_parameters=	1,
};

_jc_gnu_xml_xpath_Test$object * _JC_JCNI_ATTR
_jc_gnu_xml_xpath_Test$method$clone$73a8d2a4d673dd95(_jc_env *const env, _jc_gnu_xml_xpath_Test$object *this, _jc_java_lang_Object$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_gnu_xml_xpath_Test$method_info$clone$73a8d2a4d673dd95);
}

//
// public abstract boolean matches(org.w3c.dom.Node, int, int)
//

static const unsigned char _jc_gnu_xml_xpath_Test$param_ptypes$matches$528a77e426fd27f8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_INT, _JC_TYPE_INT, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_gnu_xml_xpath_Test$param_types$matches$528a77e426fd27f8[] = {
	&_jc_org_w3c_dom_Node$type,
	&_jc_int$prim$type,
	&_jc_int$prim$type
};

_jc_method _jc_gnu_xml_xpath_Test$method_info$matches$528a77e426fd27f8 = {
	.name=			"matches",
	.signature=		"(Lorg/w3c/dom/Node;II)Z",
	.class=			&_jc_gnu_xml_xpath_Test$type,
	.param_types=		&_jc_gnu_xml_xpath_Test$param_types$matches$528a77e426fd27f8,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_gnu_xml_xpath_Test$param_ptypes$matches$528a77e426fd27f8,
	.signature_hash=	_JC_JLONG(0x528a77e426fd27f8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_gnu_xml_xpath_Test$method$matches$528a77e426fd27f8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_xpath_Test$vtable, gnu_xml_xpath_Test.matches$528a77e426fd27f8) / sizeof(void *),
	.num_parameters=	3,
};

jboolean _JC_JCNI_ATTR
_jc_gnu_xml_xpath_Test$method$matches$528a77e426fd27f8(_jc_env *const env, _jc_gnu_xml_xpath_Test$object *this, _jc_object *param0, jint param1, jint param2)
{
	_JC_ABSTRACT_METHOD(env, &_jc_gnu_xml_xpath_Test$method_info$matches$528a77e426fd27f8);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_xpath_Test$methods[] = {
	&_jc_gnu_xml_xpath_Test$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_xml_xpath_Test$method_info$clone$73a8d2a4d673dd95,
	&_jc_gnu_xml_xpath_Test$method_info$matches$528a77e426fd27f8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_xpath_Test$instanceof_hash_bucket_23[] = {
	&_jc_gnu_xml_xpath_Test$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_xpath_Test$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_xpath_Test$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[23]=	_jc_gnu_xml_xpath_Test$instanceof_hash_bucket_23,
	[101]=	_jc_gnu_xml_xpath_Test$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_xpath_Test$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "org/w3c/dom/Node",	_JC_JLONG(0x2f4d9ed11c447a44) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_xpath_Test$vtype _jc_gnu_xml_xpath_Test$type = {
    .type= {
	.name=			"gnu/xml/xpath/Test",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xd99963ba20fa6197),
		.source_file=		"Test.java",
		.instance_size=		sizeof(_jc_gnu_xml_xpath_Test$refs) + sizeof(_jc_gnu_xml_xpath_Test$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_xml_xpath_Test$methods) / sizeof(*_jc_gnu_xml_xpath_Test$methods),
		.methods=		_jc_gnu_xml_xpath_Test$methods,
		.instanceof_hash_table=	_jc_gnu_xml_xpath_Test$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_xpath_Test$class_depends) / sizeof(*_jc_gnu_xml_xpath_Test$class_depends),
		.class_depends=		_jc_gnu_xml_xpath_Test$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_xpath_Test= {
	    .clone$73a8d2a4d673dd95=
		&_jc_gnu_xml_xpath_Test$method$clone$73a8d2a4d673dd95,
	    .matches$528a77e426fd27f8=
		&_jc_gnu_xml_xpath_Test$method$matches$528a77e426fd27f8,
	},
    }
};
